colour.appearance.rlab Module — Colour 0.3.0 documentation

# colour.appearance.rlab Module

## RLAB Colour Appearance Model

Defines RLAB colour appearance model objects:

- `RLAB_VIEWING_CONDITIONS`
- `RLAB_D_FACTOR`
- `RLAB_Specification`
- `XYZ_to_RLAB()`

See also

RLAB Colour Appearance Model IPython Notebook

References

[1] | Mark D. Fairchild, Refinement of the RLAB color space, Color Research & Application, Volume 21, Issue 5, pages 338–346, October 1996, https://ritdml.rit.edu/bitstream/handle/1850/7857/MFairchildArticle12-06-1998.pdf (Last accessed 16 August 2014)

[2] | Mark D. Fairchild, Color Appearance Models, 3nd Edition, The Wiley-IS&T Series in Imaging Science and Technology, published June 2013, ASIN: B00DAYO8E2, locations 6019-6178.

`colour.appearance.rlab.` `R_MATRIX` = array([[ 1.9569, -1.1882, 0.2313], [ 0.3612, 0.6388, 0. ], [ 0. , 0. , 1. ]])

  RLAB colour appearance model precomputed helper matrix.

  R_MATRIX : array_like, (3, 3)

`colour.appearance.rlab.` `RLAB_VIEWING_CONDITIONS` = CaseInsensitiveMapping({u'Dark': 0.2857142857142857, u'Dim': 0.3448275862068966, u'Average': 0.4347826086956522})

  Reference RLAB colour appearance model viewing conditions.

  RLAB_VIEWING_CONDITIONS : dict
    (‘Average’, ‘Dim’, ‘Dark’)

`colour.appearance.rlab.` `RLAB_D_FACTOR` = CaseInsensitiveMapping({u'Soft Copy Images': 0, u'Projected Transparencies, Dark Room': 0.5, u'soft_cp_img': 0, u'Hard Copy Images': 1, u'projected_dark': 0.5, u'hard_cp_img': 1})

  RLAB colour appearance model Discounting-the-Illuminant factor values.

  RLAB_D_FACTOR : dict
    (‘Hard Copy Images’, ‘Soft Copy Images’, ‘Projected Transparencies, Dark Room’)

  Aliases:

  - ‘hard_cp_img’: ‘Hard Copy Images’
  - ‘soft_cp_img’: ‘Soft Copy Images’
  - ‘projected_dark’: ‘Projected Transparencies, Dark Room’

class `colour.appearance.rlab.` `RLAB_ReferenceSpecification`

  Bases: `colour.appearance.rlab.RLAB_ReferenceSpecification`

  Defines the RLAB colour appearance model reference specification.

  This specification has field names consistent with Mark D. Fairchild reference.

  Parameters: | LR (numeric) – Correlate of Lightness \(L^R\). CR (numeric) – Correlate of achromatic chroma \(C^R\). hR (numeric) – Hue angle \(h^R\) in degrees. sR (numeric) – Correlate of saturation \(s^R\). HR (numeric) – Hue \(h\) composition \(H^R\). aR (numeric) – Red–green chromatic response \(a^R\). bR (numeric) – Yellow–blue chromatic response \(b^R\).

class `colour.appearance.rlab.` `RLAB_Specification`

  Bases: `colour.appearance.rlab.RLAB_Specification`

  Defines the RLAB colour appearance model specification.

  This specification has field names consistent with the remaining colour appearance models in `colour.appearance` but diverge from Mark D. Fairchild reference.

  Parameters: | J (numeric) – Correlate of Lightness \(L^R\). C (numeric) – Correlate of achromatic chroma \(C^R\). h (numeric) – Hue angle \(h^R\) in degrees. s (numeric) – Correlate of saturation \(s^R\). HC (numeric) – Hue \(h\) composition \(H^C\). a (numeric) – Red–green chromatic response \(a^R\). b (numeric) – Yellow–blue chromatic response \(b^R\).

`colour.appearance.rlab.` `XYZ_to_RLAB`(XYZ, XYZ_n, Y_n, sigma=0.4347826086956522, D=1)

  Computes the RLAB model color appearance correlates.

  Parameters: | XYZ (array_like, (3, n)) – CIE XYZ colourspace matrix of test sample / stimulus in domain [0, 100]. XYZ_n (array_like, (3,)) – CIE XYZ colourspace matrix of reference white in domain [0, 100]. Y_n (numeric) – Absolute adapting luminance in \(cd/m^2\). sigma (numeric, optional) – Relative luminance of the surround, see `RLAB_VIEWING_CONDITIONS` for reference. D (numeric, optional) – Discounting-the-Illuminant factor in domain [0, 1].
  Returns: | RLAB colour appearance model specification.
  Return type: | RLAB_Specification

  Warning

  The input domain of that definition is non standard!

  Notes

  - Input CIE XYZ colourspace matrix is in domain [0, 100].
  - Input CIE XYZ_n colourspace matrix is in domain [0, 100].

  Examples

      >>> XYZ = np.array([19.01, 20, 21.78])
      >>> XYZ_n = np.array([109.85, 100, 35.58])
      >>> Y_n = 31.83
      >>> sigma = RLAB_VIEWING_CONDITIONS['Average']
      >>> D = RLAB_D_FACTOR['Hard Copy Images']
      >>> XYZ_to_RLAB(XYZ, XYZ_n, Y_n, sigma, D)
      RLAB_Specification(J=49.8347069..., C=54.8700585..., h=286.4860208..., s=1.1010410..., HC=None, a=15.5711021..., b=-52.6142956...)